<?php
declare(strict_types = 1);
namespace Drush\Commands\radix;

use Consolidation\AnnotatedCommand\CommandData;
use Consolidation\AnnotatedCommand\CommandError;
use Drupal\Component\Utility\UrlHelper;
use Drush\Commands\radix\SubThemeGenerator;
use Drush\Commands\DrushCommands;

/**
 * Class SubThemeCommands.
 */
class SubThemeCommands extends DrushCommands {
  /**
   * Creates a Radix sub-theme.
   *
   * @command radix:create
   * @aliases radix
   * @param string $name The machine-readable name of your sub-theme.
   *
   * @bootstrap full
   *
   * @usage drush radix:create 'My Theme'
   *   Creates a Radix sub-theme called "My Theme", using the default options.
   * @usage drush radix:create 'My Theme' --machine_name=my_theme
   *   Creates a Radix sub-theme called "My Theme" with a specific machine name.
   */
  public function generateSubTheme(string $name) {
    $themeName = $name;

    $processCopyStarterkit = new \Symfony\Component\Process\Process([
        "cp", "-R", "../web/themes/contrib/radix/src/kits/radix_starterkit", "../web/themes/custom/radix_starterkit",
    ]);
    $processCopyStarterkit->run();

    $processGenerateSubtheme = new \Symfony\Component\Process\Process([
        "php", "../web/core/scripts/drupal", "generate-theme", "--starterkit", "radix_starterkit", $themeName, "--path", "themes/custom",
    ]);
    $processGenerateSubtheme->run();

    $processRemoveCopiedStarterkit = new \Symfony\Component\Process\Process([
        "rm", "-rf", "web/themes/custom/radix_starterkit/",
    ]);
    $processRemoveCopiedStarterkit->run();

    // executes after the command finishes
    if (!$processCopyStarterkit->isSuccessful()) {
      throw new \Symfony\Component\Process\Exception\ProcessFailedException($processCopyStarterkit);
  }
  
  if (!$processGenerateSubtheme->isSuccessful()) {
      throw new \Symfony\Component\Process\Exception\ProcessFailedException($processGenerateSubtheme);
  }
  
  if (!$processRemoveCopiedStarterkit->isSuccessful()) {
      throw new \Symfony\Component\Process\Exception\ProcessFailedException($processRemoveCopiedStarterkit);
  }
    
    return $processCopyStarterkit->getOutput() . $processGenerateSubtheme->getOutput() . $processRemoveCopiedStarterkit->getOutput();
}


  /**
   * {@inheritdoc}
   *
   * @hook validate radix:create
   */
  public function onHookValidateRadixGenerateSubTheme(CommandData $commandData): ?CommandError {
    // Validate $name and other inputs here if necessary.
    return NULL;
  }
}
